@@ -7,14 +7,12 @@ from monitor.entities.SmartBOT import SmartBOT
 from monitor.entities.performance.ScreenshotStatistics import ScreenshotStatistics
 from monitor.utils.ImageResizer import ImageResizer
 
-screenshots: []
-
 
 class ScreenShotGenerator(object):
+    screenshots = list()
     counter = 0
     smartBOT: SmartBOT
     interval = 1
-
     CAPTURE_SCREENSHOT = "adb -s {} shell screencap /sdcard/{}/{}.png"
     last_file: object
 
@@ -31,7 +29,7 @@ class ScreenShotGenerator(object):
                 print(error)
             screenshot = ScreenshotStatistics()
             screenshot.interval = itr
-            screenshots.append(screenshot)
+            self.screenshots.append(screenshot)
             sleep(0.3)
 
     def capture_screenshots(self, interval):
